@@ -352,6 +352,12 @@ def test_svn_urljoin(base_url, paths_to_join, expected_result):
             "http://svn.example.org/repos/test",
             ("external", "http://svn.thirdparty.com/repos/test", None, False),
         ),
+        (
+            ".external http://svn.thirdparty.com/repos/test",
+            "tags",
+            "http://svn.example.org/repos/test",
+            (".external", "http://svn.thirdparty.com/repos/test", None, False),
+        ),
         (
             "external/ http://svn.thirdparty.com/repos/test",
             "tags",
